function [pvus_est, pvus_ci, Z, pval] = estimatePVUS(X, D, bndtyp1, bnd1, bndtyp2, bnd2, method)
    % The routine can accept the input arguments: 
     % X = the data as a column vector
     % D = disease status indicator as a column vector of 1, 2, and 3 for
     %     each disease status
     % The region of interest (p,q)
     % The method which can be 'normal', 'boxcox', 'kde_err_sym', 
     %    or 'bc_kde_sym'
     % Output:
     %  * the graph, 
     %  * the corresponding graph, 
     %  * the pVUS (if it is in the feasible region)
     %  * along with the confidence intervals
     %  * the p-value for the hypothosis test comparing pVUS to pVUS|H0
%     arguments
%         X (:,1) {mustBeNumeric}
%         D (:,1) {mustBeNumeric}
%         bndtyp1 (1,1) string
%         bnd1 (1,2) {mustBeNumeric}
%         bndtyp2 (1,1) string
%         bnd2 (1,2) {mustBeNumeric}
%         method (1,1) string
%     end
    
% Check that disease status contains values 1,2,3 only
    Dsrt = sort(unique(D));
    if Dsrt(1) ~= 1 || Dsrt(2) ~= 2 || Dsrt(3) ~=3
        error('Invalid Disease Statuses. D should be a column vector of 3 Disease statuses: 1, 2, and 3')
    end

% Set Measurements from each group
    X1 = X(D == 1); % group 1
    X2 = X(D == 2); % group 2
    X3 = X(D == 3); % group 3
    
% pVUS(TC1, TC3)   
    if (strcmp(bndtyp1, 'tc1') && strcmp(bndtyp2, 'tc3')) 
        bnds = [1 3];
        p1 = min(bnd1); p2 = max(bnd1); % Set bounds on TC1 
        q1 = min(bnd2); q2 = max(bnd2); % Set bounds on TC3
    elseif (strcmp(bndtyp1, 'tc3') && strcmp(bndtyp2, 'tc1'))
        bnds = [1 3];
        p1 = min(bnd2); p2 = max(bnd2); % Set bounds on TC1
        q1 = min(bnd1); q2 = max(bnd1); % Set bounds on TC3
% pVUS(TC2, TC3)
    elseif (strcmp(bndtyp1, 'tc2') && strcmp(bndtyp2, 'tc3')) 
        bnds = [2 3];
        p1 = min(bnd2); p2 = max(bnd2); % Set bounds on TC3
        q1 = min(bnd1); q2 = max(bnd1); % Set bounds on TC2
    elseif (strcmp(bndtyp1, 'tc3') && strcmp(bndtyp2, 'tc2')) 
        bnds = [2 3];
        p1 = min(bnd1); p2 = max(bnd1); % Set bounds on TC3
        q1 = min(bnd2); q2 = max(bnd2); % Set bounds on TC2
% pVUS(TC1, TC2)
    elseif (strcmp(bndtyp1, 'tc1') && strcmp(bndtyp2, 'tc2'))
        bnds = [1 2];
        p1 = min(bnd1); p2 = max(bnd1); % Set bounds on TC1
        q1 = min(bnd2); q2 = max(bnd2); % Set bounds on TC2
    elseif (strcmp(bndtyp1, 'tc2') && strcmp(bndtyp2, 'tc1'))
        bnds = [1 2];
        p1 = min(bnd2); p2 = max(bnd2); % Set bounds on TC1
        q1 = min(bnd1); q2 = max(bnd1); % Set bounds on TC2
    else
% Throw Error 
        error('Invalid boundary types. Boundary types should be some combination of tc1, tc2, and tc3.');
    end

% pVUS(TC1, TC3) 
    if bnds == [1 3]
        pv = pVUSest(X1, X2, X3, p1, p2, q1, q2, method, true, 0.005);
% pVUS(TC2, TC3) 
    elseif bnds == [2 3]
        pv = pVUS_tc2_tc3_est(X1, X2, X3, p1, p2, q1, q2, method, true, 0.005);
% pVUS(TC1, TC2) 
    elseif bnds == [1 2]
        pv = pVUS_tc1_tc2_est(X1, X2, X3, p1, p2, q1, q2, method, true, 0.005);
    else
        error('This will never happen.');
    end
    isvalid = pv.isvalid;
    
% Options for ROC surface/pVUS plot
    fnt = 12; % Font Size
    sColor = '#B831D4'; % Side color
    fColor = '#5E236B'; % Floor and surface color
    if bnds == [1 3] 
        ttl = '$pVUS_{TC_1, TC_3}$';
        lgtopts = {'Position',[-0.2,-0.97,0.13]};
    elseif bnds == [2 3]
        ttl = '$pVUS_{TC_2, TC_3}$';
        lgtopts = {'Position',[0.15 0.7 0.2]};
    else
        ttl = '$pVUS_{TC_1, TC_2}$';
        lgtopts = {'Position',[0.1,-0.1,1.0]}; 
    end
    ttlopts = {'Interpreter','latex','FontSize',fnt+2};
    sideopts = {'EdgeColor','none', 'FaceAlpha',0.6,'BackFaceLighting','unlit',...
        'FaceColor',sColor, 'DiffuseStrength', 0.95};
    surfopts = {'EdgeColor','none','FaceColor',fColor};
    rocopts = {'EdgeColor', 'none'};
    boundopts = {'--k','Color','black'};
    fropts = {'EdgeColor', '#008FD6'};
    flooropts = {'FaceAlpha', 0, 'EdgeColor', 'black'};
    axopts = {'TickLabelInterpreter','latex','TickDir','out',...
        'TickLength',[0.02, 0.02],'Projection','perspective','FontSize',fnt};
    lbl = [0 0.2, 0.4, 0.6, 0.8, 1]; 
    clbaropts = {'Limits',[0 1],'Ticks',lbl,'TickLabels',lbl,'Location',...
        'EastOutside','TickDirection','out','TickLength', 0.01,'LineWidth',1,...
        'TickLabelInterpreter', 'latex','FontSize',fnt};
    figopts = {'Position',[408 100 500 420]};
    vw = [-40 22];
    
% If boundaries are in the feasible region
    if isvalid
% Set Estimated pVUS and 95% confidence interval
        pvus_est = pv.pvus;
        pvus_ci = pv.pvus_ci;
        Z = pv.Zstat;
        pval = pv.pval;
% Plot ROC surface with pVUS
        figure;
        pv.plotSides(sideopts{:}); hold on; % plot sides of pvus
        pv.plotFloor(surfopts{:});          % plot floor of pvus
        pv.plotSurfWithROC(surfopts{:});    % plot ROC with pvus region on the surface
        pv.plotBounds(boundopts{:});        % plot boundaries of pvus
        pv.plotBoundFloor(flooropts{:}); hold off;  % plot boundary floor
        light(lgtopts{:});                  % add light
        view(vw);
        box on;
        title(['ROC Surface with ' ttl], ttlopts{:}); % add title
        set(gca,axopts{:});                 % set axis options
        colorbar(clbaropts{:});             % add colorbar
        set(gcf,figopts{:});                % set figure options 
% If boundaries are NOT in the feasible region
    else
        warning(['The restricted region is not in the feasible region for',...
            ' the estimated ROC Surface. Please enter different boundaries',...
            ' to obtain an estimate of pVUS.']);
        pvus_est = NaN;
        pvus_ci = [NaN NaN];
% Plot ROC Surface with selected boundaries
        figure;
        pv.plotROC(rocopts{:}); hold on;    % plot ROC surface
        pv.plotBounds(boundopts{:});        % plot boundaries of pvus
        pv.plotBoundFloor(flooropts{:}); hold off;  % plot boundary floor
        view(vw);
        title('ROC Surface', ttlopts{:});   % add title
        box on; hold off;
        set(gca,axopts{:});                 % set axis options
        colorbar(clbaropts{:});             % add colorbar
        set(gcf,figopts{:});                % set figure options 
 % Plot Feasible Region
        figure;
        pv.plotFeasReg(fropts{:}); hold on;
        pv.plotBoundFloor(flooropts{:}); hold off;
        view(vw);
        set(gca,axopts{:});                     % set axis options
        set(gcf,'Position',[408 100 450 420]);  % set figure options 
        title(['Feasible Region for ' ttl], ttlopts{:});   % add title
    end
end
