function [vus_est, vus_ci, Z, pval] = estimateVUS(X, D, method)
    % The routine can accept the input arguments: 
     % X = the data as a column vector
     % D = disease status indicator as a column vector of 1, 2, and 3 for
     %     each disease status
     % The region of interest (p,q)
     % The method which can be 'normal', 'boxcox', 'kde_err_sym', 
     %    or 'bc_kde_sym'
     % Output:
     %  * the graph
     %  * the VUS
     %  * along with the confidence intervals
     %  * the p-value for the hypothosis test comparing VUS to 1/6
%     arguments
%         X (:,1) {mustBeNumeric}
%         D (:,1) {mustBeNumeric}
%         method (1,1) string
%     end
    
% Check that disease status contains values 1,2,3 only
    Dsrt = sort(unique(D));
    if Dsrt(1) ~= 1 || Dsrt(2) ~= 2 || Dsrt(3) ~=3
        error('Invalid Disease Statuses. D should be a column vector of 3 Disease statuses: 1, 2, and 3')
    end

% Set Measurements from each group
    X1 = X(D == 1); % group 1
    X2 = X(D == 2); % group 2
    X3 = X(D == 3); % group 3

    v = VUSest(X1, X2, X3, method, true, 0.005);
    
% Options for ROC surface plot
    fnt = 12; % Font Size
    ttlopts = {'Interpreter','latex','FontSize',fnt+2};
    surfopts = {'EdgeColor','none'};
    axopts = {'TickLabelInterpreter','latex','TickDir','out',...
        'TickLength',[0.02, 0.02],'Projection','perspective','FontSize',fnt};
    lbl = [0 0.2, 0.4, 0.6, 0.8, 1]; 
    clbaropts = {'Limits',[0 1],'Ticks',lbl,'TickLabels',lbl,'Location',...
        'EastOutside','TickDirection','out','TickLength', 0.01,'LineWidth',1,...
        'TickLabelInterpreter', 'latex','FontSize',fnt};
    figopts = {'Position',[408 100 500 420]};
    vw = [-40 22];
    
% Set Estimated VUS and 95% confidence interval
    vus_est = v.vus;
    vus_ci = v.vus_ci;
    pval = v.pval;
    Z = v.Zstat;
% Plot ROC surface
    figure;
    v.plotROC(surfopts{:}); 
    view(vw);
    box on;
    title('ROC Surface', ttlopts{:}); % add title
    set(gca,axopts{:});               % set axis options
    colorbar(clbaropts{:});           % add colorbar
    set(gcf,figopts{:});              % set figure options 
end
